@@ -53,7 +53,7 @@ __END__
 
 =head1 NAME
 
-OP::IPv4Addr
+OP::IPv4Addr - Overloaded IPv4 address object class
 
 =head1 VERSION
 
@@ -67,8 +67,6 @@ OP::IPv4Addr
 
 =head1 DESCRIPTION
 
-Overloaded IPv4 address object.
-
 Extends L<OP::Str>. Uses L<Data::Validate::IP> to verify input.
 
 =head1 PUBLIC CLASS METHODS
