@@ -12,12 +12,10 @@
 
 =head1 NAME
 
-OP::Ref
+OP::Ref - Object class for references
 
 =head1 DESCRIPTION
 
-Object class for references.
-
 Extends L<OP::Any>
 
 =head1 SYNOPSIS
